aboutsummaryrefslogtreecommitdiffstats
path: root/src/gaudio/driver_record.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gaudio/driver_record.h')
-rw-r--r--src/gaudio/driver_record.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gaudio/driver_record.h b/src/gaudio/driver_record.h
index 252cae5c..20136dd7 100644
--- a/src/gaudio/driver_record.h
+++ b/src/gaudio/driver_record.h
@@ -34,19 +34,19 @@
* @iclass
* @notapi
*/
-GAudioData *gaudioRecordGetFreeBlockI(void);
+#define gaudioRecordGetFreeBlockI() gfxBufferGetI()
/**
* @brief Save a block of recorded audio data ready for the application
*
* @param[in] paud The GAudioData block with data.
*
* @note Defined in the high level GAUDIO code for use by the GAUDIO record drivers.
*
* @iclass
* @notapi
*/
-void gaudioRecordSaveDataBlockI(GAudioData *paud);
+void gaudioRecordSaveDataBlockI(GDataBuffer *paud);
/**
* @brief Signal that all recording has now stopped
@@ -34,19 +34,19 @@
* @brief Save a block of recorded audio data ready for the application
*
- * @param[in] paud The GAudioData block with data.
+ * @param[in] paud The GDataBuffer block with data.
*
* @note Defined in the high level GAUDIO code for use by the GAUDIO record drivers.